"""recent.py - Recent files handler."""

import urllib

import gtk

from preferences import prefs


class RecentFilesMenu(gtk.RecentChooserMenu):

    def __init__(self, ui, window):
        self._window = window
        self._manager = gtk.recent_manager_get_default()
        gtk.RecentChooserMenu.__init__(self, self._manager)

        self.set_sort_type(gtk.RECENT_SORT_MRU)
        self.set_show_tips(True)

        rfilter = gtk.RecentFilter()
        rfilter.add_pixbuf_formats()
        rfilter.add_mime_type('application/x-zip')
        rfilter.add_mime_type('application/zip')
        rfilter.add_mime_type('application/x-rar')
        rfilter.add_mime_type('application/x-tar')
        rfilter.add_mime_type('application/x-gzip')
        rfilter.add_mime_type('application/x-bzip2')
        rfilter.add_mime_type('application/x-cbz')
        rfilter.add_mime_type('application/x-cbr')
        rfilter.add_mime_type('application/x-cbt')
        self.add_filter(rfilter)

        self.connect('item_activated', self._load)

    def _load(self, *args):
        self._window.file_handler.open_file(self.get_path(self.get_current_uri()))

    def add(self, path):
        if not prefs['store recent file info']:
            return
        self._manager.add_item(self.get_uri(path))

    def get_path(self, uri):
        return urllib.url2pathname(uri[7:])

    def get_uri(self, path):
        return 'file://' + urllib.pathname2url(path)

    def get_filename(self, path):
        values = path.split('/')
        if (len(values) > 1): return values[len(values)-1]
        return ''

    def save_page_info(self, current_page, current_filename, is_last_page):
        try:
            items = self._window.ui_manager.recent._manager.get_items()
            recent_page_info = prefs['recent_page_info']
            new_recent_page_info = {}
            item_length = len(items)
            if item_length > 0:
                for i in range(item_length):
                    uri = items[i].get_uri()
                    filename = self.get_filename(self.get_path(uri))
                    if (filename == current_filename):
                        if (current_page > 1 and not is_last_page): new_recent_page_info[filename] = current_page
                    elif (filename in recent_page_info): new_recent_page_info[filename] = recent_page_info[filename]
            prefs['recent_page_info'] = new_recent_page_info
        except: print 'No recent page info'
